from ._subscript import table_subscript
from ._smallcaps import table_smallcaps
from ._emoji import table_emoji
from ._bold import table_bold
from ._handwriting import table_handwriting
from ._italic import table_italic
from ._demonic import table_demonic
from ._fancy import table_fancy

__all__ = [
    'table_subscript',
    'table_smallcaps',
    'table_emoji',
    'table_bold',
    'table_handwriting',
    'table_italic',
    'table_demonic',
    'table_fancy'
]



import setuptools

with open('README.md', 'r') as f:
    long_description = f.read()

setuptools.setup(
    name='smoltext',
    version='1.0.0',
    scripts=['smoltext'],
    author='Sofi',
    description='A font converter utility with the extra fonts included in utf8.',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://gitlab.com/imsofi/smoltext/',
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
